@@ -142,10 +142,13 @@ class DetectorNode(Node):
 
             detection_data = data.get('detections', {})
             if detection_data and self.detector_logic.is_initialized:
-                detections = from_dict(data_class=Detections, data=detection_data)
+                try:
+                    detections = from_dict(data_class=Detections, data=detection_data)
+                except Exception as e:
+                    self.log.exception('could not parse detections')
+                    return {'error': str(e)}
                 detections = self.add_category_id_to_detections(self.detector_logic.model_info, detections)
             else:
-                print(f'No detections: {detection_data}', flush=True)
                 detections = Detections()
 
             tags = data.get('tags', [])
@@ -292,6 +295,8 @@ class DetectorNode(Node):
             self.log.error('could not reload app')
 
     async def get_detections(self, raw_image: np.ndarray, camera_id: Optional[str], tags: List[str], autoupload: Optional[str] = None) -> Optional[Dict]:
+        """Note: raw_image is a numpy array of type uint8, but not in the correrct shape!
+        It can be converted e.g. using cv2.imdecode(raw_image, cv2.IMREAD_COLOR)"""
         loop = asyncio.get_event_loop()
         detections: Detections = await loop.run_in_executor(None, self.detector_logic.evaluate, raw_image)
 
